[quake3-commits] r2084 - trunk/code/qcommon

DONOTREPLY at icculus.org DONOTREPLY at icculus.org
Sat Jul 16 07:06:56 EDT 2011


Author: thilo
Date: 2011-07-16 07:06:56 -0400 (Sat, 16 Jul 2011)
New Revision: 2084

Modified:
   trunk/code/qcommon/cmd.c
Log:
Bug 5075 - Fix comments in quake3 configs, patch by q3urt.undead at gmail.com


Modified: trunk/code/qcommon/cmd.c
===================================================================
--- trunk/code/qcommon/cmd.c	2011-07-15 16:51:54 UTC (rev 2083)
+++ trunk/code/qcommon/cmd.c	2011-07-16 11:06:56 UTC (rev 2084)
@@ -176,6 +176,11 @@
 	char	line[MAX_CMD_LINE];
 	int		quotes;
 
+	// This will keep // style comments all on one line by not breaking on
+	// a semicolon.  It will keep /* ... */ style comments all on one line by not
+	// breaking it for semicolon or newline.
+	qboolean in_star_comment = qfalse;
+	qboolean in_slash_comment = qfalse;
 	while (cmd_text.cursize)
 	{
 		if ( cmd_wait > 0 ) {
@@ -185,7 +190,7 @@
 			break;
 		}
 
 		// find a \n or ; line break
 		text = (char *)cmd_text.data;
 
 		quotes = 0;
@@ -193,10 +198,29 @@
 		{
 			if (text[i] == '"')
 				quotes++;
-			if ( !(quotes&1) &&  text[i] == ';')
-				break;	// don't break if inside a quoted string
-			if (text[i] == '\n' || text[i] == '\r' )
+
+			if ( !(quotes&1)) {
+				if (i < cmd_text.cursize - 1) {
+					if (! in_star_comment && text[i] == '/' && text[i+1] == '/')
+						in_slash_comment = qtrue;
+					else if (! in_slash_comment && text[i] == '/' && text[i+1] == '*')
+						in_star_comment = qtrue;
+					else if (in_star_comment && text[i] == '*' && text[i+1] == '/') {
+						in_star_comment = qfalse;
+						// If we are in a star comment, then the part after it is valid
+						// Note: This will cause it to NUL out the terminating '/'
+						// but ExecuteString doesn't require it anyway.
+						i++;
+						break;
+					}
+				}
+				if (! in_slash_comment && ! in_star_comment && text[i] == ';')
+					break;
+			}
+			if (! in_star_comment && (text[i] == '\n' || text[i] == '\r')) {
+				in_slash_comment = qfalse;
 				break;
+			}
 		}
 
 		if( i >= (MAX_CMD_LINE - 1)) {
@@ -185,7 +190,7 @@
 		}
 
-		// find a \n or ; line break
+		// find a \n or ; line break or comment: // or /* */
 		text = (char *)cmd_text.data;
 



More information about the quake3-commits mailing list